@@ -8,7 +8,6 @@ from compas.utilities import DataEncoder
 from compas.utilities import DataDecoder
 
 import compas
-import os
 
 import time
 import inspect
@@ -89,7 +88,7 @@ class Proxy():
 
     """
 
-    def __init__(self, host='127.0.0.1', port=9000, background=True, errorHandler=None):
+    def __init__(self, host='127.0.0.1', port=9000, background=True, errorHandler=None, once=True):
         """init function that starts a remote server then assigns corresponding client(websockets/.net) to the proxy"""
         self._python = compas._os.select_python(None)
         self.host = host
@@ -98,6 +97,11 @@ class Proxy():
         self.client = self.try_reconnect()
         if not self.client:
             self.client = self.start_server()
+            if once:
+                print("Server will shut down once program finish")
+                self.once()
+            else:
+                print("Server will keep running after progrom finish")
         self.callbacks = {}
         self.errorHandler = errorHandler
 
@@ -218,7 +222,7 @@ class Proxy():
         """use Popen to start a remote server in background"""
         env = compas._os.prepare_environment()
 
-        args = [self._python, '-m', 'compas_cloud.server', str(self.port)]
+        args = [self._python, '-m', 'compas_cloud.server', '--port', str(self.port)]
 
         if self.background:
             print("Starting new cloud server in background at {}:{}".format(self.host, self.port))
@@ -226,8 +230,7 @@ class Proxy():
         else:
             print("Starting new cloud server with prompt console at {}:{}".format(self.host, self.port))
             args[0] = compas._os.select_python('python')
-            args = " ".join(args)
-            os.system('start '+args)
+            self._process = Popen(args, env=env)
         # import sys
         # self._process = Popen(args, stdout=sys.stdout, stderr=sys.stderr, env=env)
 
@@ -241,15 +244,13 @@ class Proxy():
                 client = Client(self.host, self.port)
             except Exception as e:
 
-                # stop trying if the subprocess is not running anymore
-                if self.background:
-                    if self._process.poll() is not None:
-                        out, err = self._process.communicate()
-                        if out:
-                            print(out.decode())
-                        if err:
-                            raise RuntimeError(err.decode())
-                        raise RuntimeError('subprocess terminated, reason unknown')
+                if self._process.poll() is not None:
+                    out, err = self._process.communicate()
+                    if out:
+                        print(out.decode())
+                    if err:
+                        raise RuntimeError(err.decode())
+                    raise RuntimeError('subprocess terminated, reason unknown')
 
                 count -= 1
                 print(e)
@@ -284,6 +285,10 @@ class Proxy():
         """check if server connection is good"""
         return self.send({'control': 'check'})
 
+    def once(self):
+        """Set the server to close once this client disconnet"""
+        return self.send({'control': 'once'})
+
 
 class Sessions_client():
 
