@@ -16,6 +16,7 @@ class CompasServerProtocol(WebSocketServerProtocol):
     """The CompasServerProtocol defines the behaviour of compas cloud server"""
     cached = {}
     sessions = None
+    server_type = "NORMAL"
 
     def onConnect(self, request):
         """print client info on connection"""
@@ -24,6 +25,8 @@ class CompasServerProtocol(WebSocketServerProtocol):
     def onClose(self, wasClean, code, reason):
         """print reason on connection closes"""
         print("WebSocket connection closed: {}".format(reason))
+        if self.server_type == "ONCE":
+            raise KeyboardInterrupt
 
     def onMessage(self, payload, isBinary):
         """process the income messages"""
@@ -104,6 +107,10 @@ class CompasServerProtocol(WebSocketServerProtocol):
         if command == 'check':
             print('check from client')
             return {'status': "I'm good"}
+        if command == 'once':
+            self.server_type = "ONCE"
+            print('Setting Server type to ONCE, server will be closed once this client disconnect.')
+            return {'status': "server type set as ONCE"}
 
         raise ValueError("Unrecognised control command")
 
@@ -193,6 +200,8 @@ class CompasServerProtocol(WebSocketServerProtocol):
 
 if __name__ == '__main__':
 
+    import argparse
+
     try:
         import asyncio
     except ImportError:
@@ -203,11 +212,15 @@ if __name__ == '__main__':
     factory = WebSocketServerFactory()
     factory.protocol = CompasServerProtocol
 
+    parser = argparse.ArgumentParser()
+    parser.add_argument("--port", default=9009)
+    args = parser.parse_args()
+
     ip = '127.0.0.1'
-    port = 9000
+    port = int(args.port)
 
     loop = asyncio.get_event_loop()
-    coro = loop.create_server(factory, '127.0.0.1', 9000)
+    coro = loop.create_server(factory, '127.0.0.1', port)
     server = loop.run_until_complete(coro)
     print("starting compas_cloud server")
     print("Listenning at %s:%s" % (ip, port))
